"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMinimatch = createMinimatch;
exports.matchesAny = matchesAny;
exports.nicePath = nicePath;
exports.normalizePath = normalizePath;
const minimatch_1 = require("minimatch");
const path_1 = require("path");
/**
 * Convert array of glob patterns to array of minimatch instances.
 *
 * Handle a few Windows-Unix path gotchas.
 */
function createMinimatch(patterns) {
    return patterns.map((pattern) => new minimatch_1.Minimatch(normalizePath(pattern).replace(/^\w:\//, ""), {
        dot: true,
    }));
}
function matchesAny(patterns, path) {
    const normPath = normalizePath(path).replace(/^\w:\//, "");
    return patterns.some((pat) => pat.match(normPath));
}
function nicePath(absPath) {
    if (!(0, path_1.isAbsolute)(absPath))
        return absPath;
    const relativePath = (0, path_1.relative)(process.cwd(), absPath);
    if (relativePath.startsWith("..")) {
        return normalizePath(absPath);
    }
    return `./${normalizePath(relativePath)}`;
}
/**
 * Normalize the given path.
 *
 * @param path  The path that should be normalized.
 * @returns The normalized path.
 */
function normalizePath(path) {
    return path.replace(/\\/g, "/");
}
